@@ -17,7 +17,11 @@ class Repository(BaseRepository):
 
         self.__session = Session()
 
-    def add(self, aggregate: AggregateRoot):
+    def add(self, aggregate: AggregateRoot) -> None:
+        self.__session.add(aggregate)
+        self.__session.commit()
+
+    def save(self, aggregate: AggregateRoot) -> None:
         self.__session.add(aggregate)
         self.__session.commit()
 
